@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0904';
+our $VERSION = '0.0906';
 
 use v5.36;
 
@@ -42,14 +42,14 @@ has control => (
 
 has value => (
     is      => 'rw',
-    isa     => Velocity, # no CC# in Types::MIDI yet
+    isa     => Maybe[Velocity], # no CC# in Types::MIDI yet
     default => undef,
 );
 
 
 has trigger => (
     is      => 'rw',
-    isa     => Velocity, # no CC# in Types::MIDI yet
+    isa     => Maybe[Velocity], # no CC# in Types::MIDI yet
     default => undef,
 );
 
@@ -113,12 +113,14 @@ has running => (
 sub add_filters ($filters, $controllers) {
     for my $params (@$filters) {
         my $port = delete $params->{port};
-        next unless $port; # skip unnamed entries
+        # skip unnamed and unknown entries
+        next if !$port || !exists $controllers->{$port};
         my $type = delete $params->{type} || 'single';
         my $event = delete $params->{event} || 'all';
         my $filter = __PACKAGE__->new(
             rtc => $controllers->{$port}
         );
+        # assume all remaining key/values are module attributes
         for my $param (keys %$params) {
             $filter->$param($params->{$param});
         }
@@ -330,7 +332,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0904
+version 0.0906
 
 =head1 SYNOPSIS
 
@@ -537,8 +539,8 @@ optional. These keys are metadata, and all others are assumed to be
 object attributes to set.
 
 The B<controllers> come from L<MIDI::RtController/open_controllers>
-and is a hash reference of C<MIDI::RtController> instances keyed by a
-MIDI input device port name.
+and is a hash reference of C<MIDI::RtController> instances keyed by
+MIDI input device port names.
 
 =head1 FILTERS
 
